"use strict";
/*
 * @Author: Mr.Hope
 * @Date: 2019-10-09 12:09:44
 * @LastEditors: Mr.Hope
 * @LastEditTime: 2020-03-22 13:53:10
 * @Description: 合并对象
 */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * 深度合并对象，合并到第一个
 *
 * @param originObject 原生对象
 * @param assignObjects 需要合并的对象
 */
exports.deepAssign = (originObject, ...assignObjects) => {
    if (assignObjects.length === 0)
        return originObject;
    /** 本次合并的对象 */
    const assignObject = assignObjects.shift();
    Object.keys(assignObject).forEach((property) => {
        if (typeof originObject[property] === 'object' &&
            !Array.isArray(originObject[property]) &&
            typeof assignObject[property] === 'object' &&
            !Array.isArray(assignObject[property]))
            exports.deepAssign(originObject[property], assignObject[property]);
        else
            originObject[property] = assignObject[property];
    });
    return exports.deepAssign(originObject, ...assignObjects);
};
/**
 * 深度合并对象，合并到最后一个
 *
 * @param assignObjects 需要合并的对象
 */
exports.deepAssignReverse = (...assignObjects) => {
    if (assignObjects.length === 0)
        throw new Error('No param is given');
    if (assignObjects.length === 1)
        return assignObjects[0];
    /** 需要合并的对象 */
    const assignObject = assignObjects.pop();
    /** 被合并的对象 */
    const originObject = assignObjects.pop();
    Object.keys(originObject).forEach((property) => {
        if (assignObject[property] === undefined)
            assignObject[property] = originObject[property];
        else if (typeof assignObject[property] === 'object' &&
            !Array.isArray(assignObject))
            exports.deepAssignReverse(originObject[property], assignObject[property]);
    });
    return exports.deepAssignReverse(...assignObjects, assignObject);
};
